# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import abi_pb2 as abi__pb2


class ForgeAppRpcStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.process_one = channel.unary_unary(
        '/forge_abi.ForgeAppRpc/process_one',
        request_serializer=abi__pb2.Request.SerializeToString,
        response_deserializer=abi__pb2.Response.FromString,
        )
    self.process = channel.stream_stream(
        '/forge_abi.ForgeAppRpc/process',
        request_serializer=abi__pb2.Request.SerializeToString,
        response_deserializer=abi__pb2.Response.FromString,
        )


class ForgeAppRpcServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def process_one(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def process(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ForgeAppRpcServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'process_one': grpc.unary_unary_rpc_method_handler(
          servicer.process_one,
          request_deserializer=abi__pb2.Request.FromString,
          response_serializer=abi__pb2.Response.SerializeToString,
      ),
      'process': grpc.stream_stream_rpc_method_handler(
          servicer.process,
          request_deserializer=abi__pb2.Request.FromString,
          response_serializer=abi__pb2.Response.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'forge_abi.ForgeAppRpc', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
